@@ -1,4 +1,3 @@
-from dataclasses import dataclass, field, replace
 from functools import reduce
 from typing import (
     Any,
@@ -39,19 +38,37 @@ try:
 
     class LocalizedError(TypedDict):
         loc: Sequence[ErrorKey]
-        msg: ErrorMsg
+        err: ErrorMsg
 
 except ImportError:
     LocalizedError = Mapping[str, Any]  # type: ignore
 
 
-@dataclass
 class ValidationError(Exception):
-    messages: Sequence[ErrorMsg] = field(default_factory=list)
-    children: Mapping[ErrorKey, "ValidationError"] = field(default_factory=dict)
+    @overload
+    def __init__(self, __message: str):
+        ...
+
+    @overload
+    def __init__(
+        self,
+        messages: Sequence[ErrorMsg] = None,
+        children: Mapping[ErrorKey, "ValidationError"] = None,
+    ):
+        ...
+
+    def __init__(
+        self,
+        messages: Union[ErrorMsg, Sequence[ErrorMsg]] = None,
+        children: Mapping[ErrorKey, "ValidationError"] = None,
+    ):
+        if isinstance(messages, str):
+            messages = [messages]
+        self.messages: Sequence[str] = messages or []
+        self.children: Mapping[ErrorKey, "ValidationError"] = children or {}
 
     def __str__(self):
-        return repr(self)
+        return f"{ValidationError.__name__}: {self.errors}"
 
     def _errors(self) -> Iterator[Tuple[List[ErrorKey], ErrorMsg]]:
         for msg in self.messages:
@@ -62,13 +79,13 @@ class ValidationError(Exception):
 
     @property
     def errors(self) -> List[LocalizedError]:
-        return [{"loc": path, "msg": error} for path, error in self._errors()]
+        return [{"loc": path, "err": error} for path, error in self._errors()]
 
     @staticmethod
     def from_errors(errors: Sequence[LocalizedError]) -> "ValidationError":
         return reduce(
             merge_errors,
-            [_rec_build_error(err["loc"], err["msg"]) for err in errors],
+            [_rec_build_error(err["loc"], err["err"]) for err in errors],
             ValidationError(),
         )
 
@@ -120,7 +137,7 @@ def apply_aliaser(error: ValidationError, aliaser: Aliaser) -> ValidationError:
         child2 = apply_aliaser(child, aliaser)
         aliased |= child2 is not child
         aliased_children[key] = child2
-    return replace(error, children=aliased_children) if aliased else error
+    return ValidationError(error.messages, aliased_children) if aliased else error
 
 
 def _rec_build_error(path: Sequence[ErrorKey], msg: ErrorMsg) -> ValidationError:
